<?php

namespace Drupal\guifi;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines the access control handler for the guifi entity type.
 */
class GuifiAccessControlHandler extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {

    switch ($operation) {
      case 'view':
        return AccessResult::allowedIfHasPermission($account, 'view guifi');

      case 'update':
        return AccessResult::allowedIfHasPermissions($account, ['edit guifi', 'administer guifi'], 'OR');

      case 'delete':
        return AccessResult::allowedIfHasPermissions($account, ['delete guifi', 'administer guifi'], 'OR');

      default:
        // No opinion.
        return AccessResult::neutral();
    }

  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermissions($account, ['create guifi', 'administer guifi'], 'OR');
  }

}
