<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'guifi_email_labeled_default' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_email_labeled_default",
 *   label = @Translation("Default"),
 *   field_types = {"guifi_email_labeled"}
 * )
 */
class EmailLabeledDefaultFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];

    foreach ($items as $delta => $item) {

      if ($item->email) {
        $element[$delta]['email'] = [
          '#type' => 'item',
          '#title' => $this->t('email'),
          'content' => [
            '#type' => 'link',
            '#title' => $item->email,
            '#url' => Url::fromUri('mailto:' . $item->email),
          ],
        ];
      }

      if ($item->label) {
        $element[$delta]['label'] = [
          '#type' => 'item',
          '#title' => $this->t('Label'),
          '#markup' => $item->label,
        ];
      }

    }

    return $element;
  }

}
