<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;

/**
 * Plugin implementation of the 'guifi_labeled_phone_default' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_labeled_phone_default",
 *   label = @Translation("Default"),
 *   field_types = {"guifi_labeled_phone"}
 * )
 */
class LabeledPhoneDefaultFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return ['foo' => 'bar'] + parent::defaultSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();
    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $settings = $this->getSettings();
    $summary[] = $this->t('Foo: @foo', ['@foo' => $settings['foo']]);
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $element = [];

    foreach ($items as $delta => $item) {

      if ($item->phone_label) {
        $element[$delta]['phone_label'] = [
          '#type' => 'item',
          '#title' => $this->t('Label'),
          '#markup' => $item->phone_label,
        ];
      }

      if ($item->phone_number) {
        $element[$delta]['phone_number'] = [
          '#type' => 'item',
          '#title' => $this->t('Number'),
          'content' => [
            '#type' => 'link',
            '#title' => $item->phone_number,
            '#url' => Url::fromUri('tel:' . rawurlencode(preg_replace('/\s+/', '', $item->phone_number))),
          ],
        ];
      }

    }

    return $element;
  }

}
