<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'guifi_labeled_phone_key_value' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_labeled_phone_key_value",
 *   label = @Translation("Key-value"),
 *   field_types = {"guifi_labeled_phone"}
 * )
 */
class LabeledPhoneKeyValueFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    $element = [];

    foreach ($items as $delta => $item) {

      $table = [
        '#type' => 'table',
      ];

      // Label.
      if ($item->phone_label) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Label'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->phone_label,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // Number.
      if ($item->phone_number) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Number'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->phone_number,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      $element[$delta] = $table;

    }

    return $element;
  }

}
