<?php

namespace Drupal\guifi\Plugin\Field\FieldFormatter;

use Drupal\Core\Datetime\DrupalDateTime;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;

/**
 * Plugin implementation of the 'guifi_sync_track_key_value' formatter.
 *
 * @FieldFormatter(
 *   id = "guifi_sync_track_key_value",
 *   label = @Translation("Key-value"),
 *   field_types = {"guifi_sync_track"}
 * )
 */
class SyncTrackKeyValueFormatter extends FormatterBase {

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {

    $element = [];

    foreach ($items as $delta => $item) {

      $table = [
        '#type' => 'table',
      ];

      // Source.
      if ($item->synctrack_source) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Source'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->synctrack_source,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // Id.
      if ($item->synctrack_id) {
        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Id'),
              ],
            ],
            [
              'data' => [
                '#markup' => $item->synctrack_id,
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      // Last sync.
      if ($item->synctrack_when) {
        $date = DrupalDateTime::createFromFormat('Y-m-d\TH:i:s', $item->synctrack_when);
        $date_formatter = \Drupal::service('date.formatter');
        $timestamp = $date->getTimestamp();
        $formatted_date = $date_formatter->format($timestamp, 'long');
        $iso_date = $date_formatter->format($timestamp, 'custom', 'Y-m-d\TH:i:s') . 'Z';

        $table['#rows'][] = [
          'data' => [
            [
              'header' => TRUE,
              'data' => [
                '#markup' => $this->t('Last sync'),
              ],
            ],
            [
              'data' => [
                '#theme' => 'time',
                '#text' => $formatted_date,
                '#html' => FALSE,
                '#attributes' => [
                  'datetime' => $iso_date,
                ],
                '#cache' => [
                  'contexts' => [
                    'timezone',
                  ],
                ],
              ],
            ],
          ],
          'no_striping' => TRUE,
        ];
      }

      $element[$delta] = $table;

    }

    return $element;
  }

}
