<?php

namespace Drupal\guifi\Plugin\Field\FieldType;

use Drupal\Component\Utility\Random;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'guifi_labeled_phone' field type.
 *
 * @FieldType(
 *   id = "guifi_labeled_phone",
 *   label = @Translation("Labeled phone"),
 *   category = @Translation("General"),
 *   default_widget = "guifi_labeled_phone",
 *   default_formatter = "guifi_labeled_phone_default"
 * )
 */
class LabeledPhoneItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    if ($this->phone_label !== NULL) {
      return FALSE;
    }
    elseif ($this->phone_number !== NULL) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {

    $properties['phone_label'] = DataDefinition::create('string')
      ->setLabel(t('Label'));
    $properties['phone_number'] = DataDefinition::create('string')
      ->setLabel(t('Number'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();

    // @todo Add more constraints here.
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {

    $columns = [
      'phone_label' => [
        'type' => 'varchar',
        'length' => 255,
      ],
      'phone_number' => [
        'type' => 'varchar',
        'length' => 255,
      ],
    ];

    $schema = [
      'columns' => $columns,
      // @DCG Add indexes here if necessary.
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {

    $random = new Random();

    $values['phone_label'] = $random->word(mt_rand(1, 255));

    $values['phone_number'] = mt_rand(pow(10, 8), pow(10, 9) - 1);

    return $values;
  }

}
