<?php

namespace Drupal\guifi\Plugin\Field\FieldType;

use Drupal\Component\Utility\Random;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'guifi_phone_labeled' field type.
 *
 * @FieldType(
 *   id = "guifi_phone_labeled",
 *   label = @Translation("Phone (labeled)"),
 *   category = @Translation("General"),
 *   default_widget = "guifi_phone_labeled",
 *   default_formatter = "guifi_phone_labeled_default"
 * )
 */
class PhoneLabeledItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    $settings = ['foo' => 'example'];
    return $settings + parent::defaultStorageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data) {
    $settings = $this->getSettings();

    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
      '#disabled' => $has_data,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    $settings = ['bar' => 'example'];
    return $settings + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();

    $element['bar'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['bar'],
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    if ($this->number !== NULL) {
      return FALSE;
    }
    elseif ($this->sms == 1) {
      return FALSE;
    }
    elseif ($this->label !== NULL) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {

    $properties['number'] = DataDefinition::create('string')
      ->setLabel(t('Phone number'));
    $properties['sms'] = DataDefinition::create('boolean')
      ->setLabel(t('SMS texts'));
    $properties['label'] = DataDefinition::create('string')
      ->setLabel(t('Label'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();

    $options['number']['NotBlank'] = [];

    $constraint_manager = \Drupal::typedDataManager()->getValidationConstraintManager();
    $constraints[] = $constraint_manager->create('ComplexData', $options);
    // @todo Add more constraints here.
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {

    $columns = [
      'number' => [
        'type' => 'varchar',
        'length' => 255,
      ],
      'sms' => [
        'type' => 'int',
        'size' => 'tiny',
      ],
      'label' => [
        'type' => 'varchar',
        'length' => 255,
      ],
    ];

    $schema = [
      'columns' => $columns,
      // @DCG Add indexes here if necessary.
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {

    $random = new Random();

    $values['number'] = mt_rand(pow(10, 8), pow(10, 9) - 1);

    $values['sms'] = (bool) mt_rand(0, 1);

    $values['label'] = $random->word(mt_rand(1, 255));

    return $values;
  }

}
