<?php

namespace Drupal\guifi\Plugin\Field\FieldType;

use Drupal\Component\Utility\Random;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;

/**
 * Defines the 'guifi_sync_track' field type.
 *
 * @FieldType(
 *   id = "guifi_sync_track",
 *   label = @Translation("Sync track"),
 *   category = @Translation("General"),
 *   default_widget = "guifi_sync_track",
 *   default_formatter = "guifi_sync_track_default"
 * )
 */
class SyncTrackItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultStorageSettings() {
    $settings = ['foo' => 'example'];
    return $settings + parent::defaultStorageSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function storageSettingsForm(array &$form, FormStateInterface $form_state, $has_data) {
    $settings = $this->getSettings();

    $element['foo'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['foo'],
      '#disabled' => $has_data,
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    $settings = ['bar' => 'example'];
    return $settings + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    $settings = $this->getSettings();

    $element['bar'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Foo'),
      '#default_value' => $settings['bar'],
    ];

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    if ($this->synctrack_source !== NULL) {
      return FALSE;
    }
    elseif ($this->synctrack_id !== NULL) {
      return FALSE;
    }
    elseif ($this->synctrack_when !== NULL) {
      return FALSE;
    }
    return TRUE;
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {

    $properties['synctrack_source'] = DataDefinition::create('string')
      ->setLabel(t('Source'));
    $properties['synctrack_id'] = DataDefinition::create('string')
      ->setLabel(t('Id'));
    $properties['synctrack_when'] = DataDefinition::create('datetime_iso8601')
      ->setLabel(t('Last sync'));

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function getConstraints() {
    $constraints = parent::getConstraints();

    // @todo Add more constraints here.
    return $constraints;
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {

    $columns = [
      'synctrack_source' => [
        'type' => 'varchar',
        'length' => 255,
      ],
      'synctrack_id' => [
        'type' => 'varchar',
        'length' => 255,
      ],
      'synctrack_when' => [
        'type' => 'varchar',
        'length' => 20,
      ],
    ];

    $schema = [
      'columns' => $columns,
      // @DCG Add indexes here if necessary.
    ];

    return $schema;
  }

  /**
   * {@inheritdoc}
   */
  public static function generateSampleValue(FieldDefinitionInterface $field_definition) {

    $random = new Random();

    $values['synctrack_source'] = $random->word(mt_rand(1, 255));

    $values['synctrack_id'] = $random->word(mt_rand(1, 255));

    $timestamp = \Drupal::time()->getRequestTime() - mt_rand(0, 86400 * 365);
    $values['synctrack_when'] = gmdate('Y-m-d\TH:i:s', $timestamp);

    return $values;
  }

}
