<?php

namespace Drupal\guifi\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Defines the 'guifi_email_labeled' field widget.
 *
 * @FieldWidget(
 *   id = "guifi_email_labeled",
 *   label = @Translation("Email (labeled)"),
 *   field_types = {"guifi_email_labeled"},
 * )
 */
class EmailLabeledWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $element['email'] = [
      '#type' => 'email',
      '#title' => $this->t('email'),
      '#default_value' => isset($items[$delta]->email) ? $items[$delta]->email : NULL,
      '#size' => 20,
    ];

    $element['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#default_value' => isset($items[$delta]->label) ? $items[$delta]->label : NULL,
      '#size' => 20,
    ];

    $element['#theme_wrappers'] = ['container', 'form_element'];
    $element['#attributes']['class'][] = 'container-inline';
    $element['#attributes']['class'][] = 'guifi-email-labeled-elements';
    $element['#attached']['library'][] = 'guifi/guifi_email_labeled';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return isset($violation->arrayPropertyPath[0]) ? $element[$violation->arrayPropertyPath[0]] : $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $delta => $value) {
      if ($value['email'] === '') {
        $values[$delta]['email'] = NULL;
      }
      if ($value['label'] === '') {
        $values[$delta]['label'] = NULL;
      }
    }
    return $values;
  }

}
