<?php

namespace Drupal\guifi\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\WidgetBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\Validator\ConstraintViolationInterface;

/**
 * Defines the 'guifi_phone_labeled' field widget.
 *
 * @FieldWidget(
 *   id = "guifi_phone_labeled",
 *   label = @Translation("Phone (labeled)"),
 *   field_types = {"guifi_phone_labeled"},
 * )
 */
class PhoneLabeledWidget extends WidgetBase {

  /**
   * {@inheritdoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {

    $element['number'] = [
      '#type' => 'tel',
      '#title' => $this->t('number'),
      '#default_value' => isset($items[$delta]->number) ? $items[$delta]->number : NULL,
    ];

    $element['sms'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('SMS texts'),
      '#default_value' => isset($items[$delta]->sms) ? $items[$delta]->sms : NULL,
    ];

    $element['label'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#default_value' => isset($items[$delta]->label) ? $items[$delta]->label : NULL,
    ];

    $element['#theme_wrappers'] = ['container', 'form_element'];
    $element['#attributes']['class'][] = 'guifi-phone-labeled-elements';
    $element['#attached']['library'][] = 'guifi/guifi_phone_labeled';

    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function errorElement(array $element, ConstraintViolationInterface $violation, array $form, FormStateInterface $form_state) {
    return isset($violation->arrayPropertyPath[0]) ? $element[$violation->arrayPropertyPath[0]] : $element;
  }

  /**
   * {@inheritdoc}
   */
  public function massageFormValues(array $values, array $form, FormStateInterface $form_state) {
    foreach ($values as $delta => $value) {
      if ($value['number'] === '') {
        $values[$delta]['number'] = NULL;
      }
      if ($value['sms'] === '') {
        $values[$delta]['sms'] = NULL;
      }
      if ($value['label'] === '') {
        $values[$delta]['label'] = NULL;
      }
    }
    return $values;
  }

}
